@@ -8,43 +8,42 @@
 
 #ifndef Q_OS_ANDROID
 #include <qt5keychain/keychain.h>
-#else
+#endif
 #include <KConfig>
 #include <KConfigGroup>
-#endif
-
+#include <KWindowConfig>
 #include <KLocalizedString>
 
 #include <QClipboard>
 #include <QDebug>
+#include <QQuickWindow>
 #include <QDir>
 #include <QElapsedTimer>
 #include <QFile>
 #include <QFileInfo>
 #include <QStandardPaths>
-#include <QStringBuilder>
 #include <QSysInfo>
 #include <QTimer>
-#include <QtGui/QCloseEvent>
-#include <QtGui/QDesktopServices>
-#include <QtGui/QMovie>
-#include <QtGui/QPixmap>
-#include <QtNetwork/QAuthenticator>
-#include <QtNetwork/QNetworkReply>
+#include <QCloseEvent>
+#include <QDesktopServices>
+#include <QMovie>
+#include <QPixmap>
+#include <QAuthenticator>
+#include <QNetworkReply>
+#include <QStringBuilder>
 #include <utility>
 
 #include "csapi/account-data.h"
 #include "csapi/content-repo.h"
-#include "csapi/joining.h"
 #include "csapi/logout.h"
 #include "csapi/profile.h"
 #include "csapi/registration.h"
 #include "csapi/wellknown.h"
 #include "events/eventcontent.h"
 #include "events/roommessageevent.h"
+#include "neochatconfig.h"
 #include "neochatroom.h"
 #include "neochatuser.h"
-#include "neochatconfig.h"
 #include "settings.h"
 #include "utils.h"
 #include <KStandardShortcut>
@@ -56,16 +55,26 @@
 Controller::Controller(QObject *parent)
     : QObject(parent)
 {
-    QApplication::setQuitOnLastWindowClosed(false);
-
     Connection::setRoomType<NeoChatRoom>();
     Connection::setUserType<NeoChatUser>();
 
 #ifndef Q_OS_ANDROID
     TrayIcon *trayIcon = new TrayIcon(this);
-    connect(trayIcon, &TrayIcon::showWindow, this, &Controller::showWindow);
-    trayIcon->setIconSource("org.kde.neochat");
-    trayIcon->setIsOnline(true);
+    if(NeoChatConfig::self()->systemTray()) {
+        trayIcon->show();
+        connect(trayIcon, &TrayIcon::showWindow, this, &Controller::showWindow);
+        QApplication::setQuitOnLastWindowClosed(false);
+    }
+    connect(NeoChatConfig::self(), &NeoChatConfig::SystemTrayChanged, this, [=](){
+        if(NeoChatConfig::self()->systemTray()) {
+            trayIcon->show();
+            connect(trayIcon, &TrayIcon::showWindow, this, &Controller::showWindow);
+        } else {
+            trayIcon->hide();
+            disconnect(trayIcon, &TrayIcon::showWindow, this, &Controller::showWindow);
+        }
+        QApplication::setQuitOnLastWindowClosed(!NeoChatConfig::self()->systemTray());
+    });
 #endif
 
     QTimer::singleShot(0, this, [=] {
@@ -93,51 +102,6 @@ inline QString accessTokenFileName(const AccountSettings &account)
     return QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation) + '/' + fileName;
 }
 
-void Controller::loginWithCredentials(const QString &serverAddr, const QString &user, const QString &pass, QString deviceName)
-{
-    if (user.isEmpty() || pass.isEmpty()) {
-        return;
-    }
-
-
-    if (deviceName.isEmpty()) {
-        deviceName = "NeoChat " + QSysInfo::machineHostName() + " " + QSysInfo::productType() + " " + QSysInfo::productVersion() + " " + QSysInfo::currentCpuArchitecture();
-    }
-
-    auto conn = new Connection(this);
-    const QUrl serverUrl = QUrl(serverAddr);
-    // we are using a fake mixd since resolveServer just set the homeserver url :sigh:
-    conn->resolveServer("@username:" + serverUrl.host() + ":" + QString::number(serverUrl.port(443)));
-
-    connect(conn, &Connection::loginFlowsChanged, this, [this, user, conn, pass, deviceName]() {
-        conn->loginWithPassword(user, pass, deviceName, "");
-        connect(conn, &Connection::connected, this, [this, conn, deviceName] {
-            AccountSettings account(conn->userId());
-            account.setKeepLoggedIn(true);
-            account.clearAccessToken(); // Drop the legacy - just in case
-            account.setHomeserver(conn->homeserver());
-            account.setDeviceId(conn->deviceId());
-            account.setDeviceName(deviceName);
-            if (!saveAccessTokenToKeyChain(account, conn->accessToken())) {
-                qWarning() << "Couldn't save access token";
-            }
-            account.sync();
-            addConnection(conn);
-            setActiveConnection(conn);
-        });
-        connect(conn, &Connection::networkError, [=](QString error, const QString &, int, int) {
-            Q_EMIT globalErrorOccured(i18n("Network Error"), std::move(error));
-        });
-        connect(conn, &Connection::loginError, [=](QString error, const QString &) {
-            Q_EMIT errorOccured(i18n("Login Failed"), std::move(error));
-        });
-    });
-
-    connect(conn, &Connection::resolveError, this, [=](QString error) {
-        Q_EMIT globalErrorOccured(i18n("Network Error"), std::move(error));
-    });
-}
-
 void Controller::loginWithAccessToken(const QString &serverAddr, const QString &user, const QString &token, const QString &deviceName)
 {
     if (user.isEmpty() || token.isEmpty()) {
@@ -260,7 +224,7 @@ void Controller::invokeLogin()
     const auto accounts = SettingsGroup("Accounts").childGroups();
     QString id = NeoChatConfig::self()->activeConnection();
     for (const auto &accountId : accounts) {
-        AccountSettings account {accountId};
+        AccountSettings account{accountId};
         if (id.isEmpty()) {
             // handle case where the account config is empty
             id = accountId;
@@ -285,6 +249,7 @@ void Controller::invokeLogin()
                     Q_EMIT errorOccured(i18n("Login Failed"), error);
                     logout(connection, true);
                 }
+                Q_EMIT initiated();
             });
             connect(connection, &Connection::networkError, this, [=](const QString &error, const QString &, int, int) {
                 Q_EMIT errorOccured("Network Error", error);
@@ -292,14 +257,14 @@ void Controller::invokeLogin()
             connection->connectWithToken(account.userId(), accessToken, account.deviceId());
         }
     }
-    if (m_connections.isEmpty()) {
+    if (accounts.isEmpty()) {
         Q_EMIT initiated();
     }
 }
 
 QByteArray Controller::loadAccessTokenFromFile(const AccountSettings &account)
 {
-    QFile accountTokenFile {accessTokenFileName(account)};
+    QFile accountTokenFile{accessTokenFileName(account)};
     if (accountTokenFile.open(QFile::ReadOnly)) {
         if (accountTokenFile.size() < 1024) {
             return accountTokenFile.readAll();
@@ -337,7 +302,7 @@ QByteArray Controller::loadAccessTokenFromKeyChain(const AccountSettings &accoun
             bool removed = false;
             bool saved = saveAccessTokenToKeyChain(account, accessToken);
             if (saved) {
-                QFile accountTokenFile {accessTokenFileName(account)};
+                QFile accountTokenFile{accessTokenFileName(account)};
                 removed = accountTokenFile.remove();
             }
             if (!(saved && removed)) {
@@ -360,7 +325,7 @@ QByteArray Controller::loadAccessTokenFromKeyChain(const AccountSettings &accoun
 bool Controller::saveAccessTokenToFile(const AccountSettings &account, const QByteArray &accessToken)
 {
     // (Re-)Make a dedicated file for access_token.
-    QFile accountTokenFile {accessTokenFileName(account)};
+    QFile accountTokenFile{accessTokenFileName(account)};
     accountTokenFile.remove(); // Just in case
 
     auto fileDir = QFileInfo(accountTokenFile).dir();
@@ -399,34 +364,6 @@ bool Controller::saveAccessTokenToKeyChain(const AccountSettings &account, const
     return true;
 }
 
-void Controller::joinRoom(Connection *c, const QString &alias)
-{
-    if (!alias.contains(":")) {
-        return;
-    }
-
-    auto knownServer = alias.mid(alias.indexOf(":") + 1);
-    auto joinRoomJob = c->joinRoom(alias, QStringList {knownServer});
-    Quotient::JoinRoomJob::connect(joinRoomJob, &JoinRoomJob::failure, [=] {
-        Q_EMIT errorOccured("Join Room Failed", joinRoomJob->errorString());
-    });
-}
-
-void Controller::createRoom(Connection *c, const QString &name, const QString &topic)
-{
-    auto createRoomJob = c->createRoom(Connection::PublishRoom, "", name, topic, QStringList());
-    Quotient::CreateRoomJob::connect(createRoomJob, &CreateRoomJob::failure, [=] {
-        Q_EMIT errorOccured("Create Room Failed", createRoomJob->errorString());
-    });
-}
-
-void Controller::createDirectChat(Connection *c, const QString &userID)
-{
-    auto createRoomJob = c->createDirectChat(userID);
-    Quotient::CreateRoomJob::connect(createRoomJob, &CreateRoomJob::failure, [=] {
-        Q_EMIT errorOccured("Create Direct Chat Failed", createRoomJob->errorString());
-    });
-}
 
 void Controller::playAudio(const QUrl &localFile)
 {
@@ -565,7 +502,21 @@ void Controller::setActiveConnection(Connection *connection)
     Q_EMIT activeConnectionChanged();
 }
 
-QList<QKeySequence> Controller::preferencesShortcuts() const
+void Controller::saveWindowGeometry(QQuickWindow *window)
 {
-    return KStandardShortcut::preferences();
+    KConfig dataResource("data", KConfig::SimpleConfig, QStandardPaths::AppDataLocation);
+    KConfigGroup windowGroup(&dataResource, "Window");
+    KWindowConfig::saveWindowPosition(window, windowGroup);
+    KWindowConfig::saveWindowSize(window, windowGroup);
+    dataResource.sync();
+}
+
+
+NeochatDeleteDeviceJob::NeochatDeleteDeviceJob(const QString &deviceId, const Omittable<QJsonObject> &auth)
+    : Quotient::BaseJob(HttpVerb::Delete, QStringLiteral("DeleteDeviceJob"), QStringLiteral("/_matrix/client/r0/devices/%1").arg(deviceId))
+{
+    QJsonObject _data;
+    addParam<IfNotEmpty>(_data, QStringLiteral("auth"), auth);
+    setRequestData(std::move(_data));
+
 }
