@@ -3,8 +3,8 @@
  *
  * SPDX-License-Identifier: GPL-3.0-only
  */
-#ifndef CONTROLLER_H
-#define CONTROLLER_H
+
+#pragma once
 
 #include <QApplication>
 #include <QMediaPlayer>
@@ -21,6 +21,7 @@ class QKeySequences;
 #include "user.h"
 
 class NeoChatRoom;
+class QQuickWindow;
 
 using namespace Quotient;
 
@@ -33,9 +34,6 @@ class Controller : public QObject
     Q_PROPERTY(bool busy READ busy WRITE setBusy NOTIFY busyChanged)
     Q_PROPERTY(KAboutData aboutData READ aboutData WRITE setAboutData NOTIFY aboutDataChanged)
 
-    /// Get the list of shortcuts activating the preferences page
-    Q_PROPERTY(QList<QKeySequence> preferencesShortcuts READ preferencesShortcuts CONSTANT)
-
 public:
     static Controller &instance();
 
@@ -47,15 +45,12 @@ public:
     void addConnection(Connection *c);
     void dropConnection(Connection *c);
 
-    Q_INVOKABLE void loginWithCredentials(const QString &, const QString &, const QString &, QString);
     Q_INVOKABLE void loginWithAccessToken(const QString &, const QString &, const QString &, const QString &);
 
     Q_INVOKABLE void changePassword(Quotient::Connection *connection, const QString &currentPassword, const QString &newPassword);
 
     [[nodiscard]] int accountCount() const;
 
-    [[nodiscard]] QList<QKeySequence> preferencesShortcuts() const;
-
     [[nodiscard]] static bool quitOnLastWindowClosed();
     void setQuitOnLastWindowClosed(bool value);
 
@@ -65,6 +60,9 @@ public:
     void setAboutData(const KAboutData &aboutData);
     [[nodiscard]] KAboutData aboutData() const;
 
+    bool saveAccessTokenToFile(const AccountSettings &account, const QByteArray &accessToken);
+    bool saveAccessTokenToKeyChain(const AccountSettings &account, const QByteArray &accessToken);
+
     enum PasswordStatus {
         Success,
         Wrong,
@@ -83,8 +81,6 @@ private:
     static QByteArray loadAccessTokenFromFile(const AccountSettings &account);
     QByteArray loadAccessTokenFromKeyChain(const AccountSettings &account);
 
-    bool saveAccessTokenToFile(const AccountSettings &account, const QByteArray &accessToken);
-    bool saveAccessTokenToKeyChain(const AccountSettings &account, const QByteArray &accessToken);
     void loadSettings();
     void saveSettings() const;
 
@@ -95,10 +91,10 @@ private Q_SLOTS:
 
 Q_SIGNALS:
     void busyChanged();
-    /// Error occured because of user inputs
+    /// Error occurred because of user inputs
     void errorOccured(QString error, QString detail);
 
-    /// Error occured because of server or bug in NeoChat
+    /// Error occurred because of server or bug in NeoChat
     void globalErrorOccured(QString error, QString detail);
     void syncDone();
     void connectionAdded(Quotient::Connection *_t1);
@@ -114,15 +110,14 @@ Q_SIGNALS:
     void showWindow();
     void openRoom(NeoChatRoom *room);
     void userConsentRequired(QUrl url);
+    void testConnectionResult(const QString &connection, bool usable);
 
 public Q_SLOTS:
     void logout(Quotient::Connection *conn, bool serverSideLogout);
-    void joinRoom(Quotient::Connection *c, const QString &alias);
-    void createRoom(Quotient::Connection *c, const QString &name, const QString &topic);
-    void createDirectChat(Quotient::Connection *c, const QString &userID);
     static void playAudio(const QUrl &localFile);
     void changeAvatar(Quotient::Connection *conn, const QUrl &localFile);
     static void markAllMessagesAsRead(Quotient::Connection *conn);
+    void saveWindowGeometry(QQuickWindow *);
 };
 
 // TODO libQuotient 0.7: Drop
@@ -132,4 +127,8 @@ public:
     explicit NeochatChangePasswordJob(const QString &newPassword, bool logoutDevices, const Omittable<QJsonObject> &auth = none);
 };
 
-#endif // CONTROLLER_H
+class NeochatDeleteDeviceJob : public BaseJob
+{
+public:
+    explicit NeochatDeleteDeviceJob(const QString &deviceId, const Omittable<QJsonObject> &auth = none);
+};
