@@ -3,8 +3,8 @@
  *
  * SPDX-License-Identifier: GPL-3.0-only
  */
-#ifndef MESSAGEEVENTMODEL_H
-#define MESSAGEEVENTMODEL_H
+
+#pragma once
 
 #include <QAbstractListModel>
 
@@ -32,6 +32,7 @@ public:
         LongOperationRole,
         AnnotationRole,
         UserMarkerRole,
+        FormattedBodyRole,
 
         ReplyRole,
 
@@ -39,6 +40,7 @@ public:
         ShowSectionRole,
 
         ReactionRole,
+
         IsEditedRole,
 
         // For debugging
@@ -89,5 +91,3 @@ private:
 Q_SIGNALS:
     void roomChanged();
 };
-
-#endif // MESSAGEEVENTMODEL_H
