@@ -3,6 +3,7 @@
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
+
 #pragma once
 
 #include <QImage>
@@ -21,7 +22,7 @@ class NotificationsManager : public QObject
 public:
     static NotificationsManager &instance();
 
-    Q_INVOKABLE void postNotification(NeoChatRoom *roomId, const QString &eventId, const QString &roomName, const QString &senderName, const QString &text, const QImage &icon);
+    Q_INVOKABLE void postNotification(NeoChatRoom *room, const QString &roomName, const QString &sender, const QString &text, const QImage &icon);
 
 private:
     NotificationsManager(QObject *parent = nullptr);
